pub struct VolumeKey(/* private fields */);Expand description
A LUKS volume key used to encrypt and decrypt the actual data on the device.
This key is derived from an UnlockKey (passphrase) and a keyslot.
It is protected while in memory and is automatically zeroed when no longer needed.
Implementations
Sourceimpl VolumeKey
impl VolumeKey
Sourcepub fn new(bytes: Vec<u8>) -> Result<Self, LuksError>
pub fn new(bytes: Vec<u8>) -> Result<Self, LuksError>
Creates a new volume key from its raw bytes.
Returns an error if the provided bytes length is not a valid LUKS volume key size.
Sourcepub fn expose_bytes(&self) -> &[u8] ⓘ
pub fn expose_bytes(&self) -> &[u8] ⓘ
Unboxes the volume key, returning its raw bytes for use in cryptographic operations.