pub struct Luks2U64(pub u64);Expand description
A 64-bit unsigned integer that is represented as a decimal string in JSON.
This is necessary because JSON’s standard number type is a double-precision floating point value (IEEE 754), which cannot accurately represent the full range of 64-bit integers without losing precision. By encoding large integers as strings, LUKS2 ensures that values like offsets and sizes remain exact.
Tuple Fields
0: u64Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Luks2U64
impl<'de> Deserialize<'de> for Luks2U64
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Ord for Luks2U64
impl Ord for Luks2U64
Sourceimpl PartialOrd for Luks2U64
impl PartialOrd for Luks2U64
impl Copy for Luks2U64
impl Eq for Luks2U64
impl StructuralPartialEq for Luks2U64